Hakai Segmentation
==================

.. image:: https://github.com/tayden/hakai-segmentation/actions/workflows/test.yml/badge.svg?branch=main&event=push
  :target: https://github.com/tayden/hakai-segmentation/actions/workflows/test.yml
  :alt: Test Status
  :height: 20px

.. image:: https://readthedocs.org/projects/hakai-segmentation/badge/?version=latest
  :target: https://hakai-segmentation.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status
  :height: 20px

.. image:: https://badgen.net/github/license/tayden/hakai-segmentation
  :target: https://github.com/tayden/hakai-segmentation/blob/main/LICENSE.txt
  :alt: License
  :height: 20px

.. image:: https://badgen.net/github/release/tayden/hakai-segmentation?icon=github
  :target: https://github.com/tayden/hakai-segmentation/releases
  :alt: License
  :height: 20px

.. image:: https://badgen.net/pypi/python/hakai-segmentation?icon=pypi
  :target: https://pypi.org/project/hakai-segmentation/
  :alt: License
  :height: 20px

Segmentation tools for remotely sensed RPAS imagery


`Read the Docs <http://hakai-segmentation.readthedocs.io/>`_
